package api

import (
	"cmf/db/model"
	"cmf/db/repo"
	"cmf/log"
	"errors"
	"time"

	"github.com/gin-gonic/gin"
	"go.mongodb.org/mongo-driver/bson/primitive"
)

func Finish(r *GinRouter) {
	r.POST("/finish/create", CreateFinish)
	r.POST("/finish/delete/:id", DeleteFinish)
	r.GET("/finish/list", FinishList)
	r.GET("/finish/detail/:id", FinishDetail)
	r.POST("/finish/update", UpdateFinish)
}

func CreateFinish(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	var finish model.Finish
	err := c.ShouldBindJSON(&finish)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	finish.CreateTime = time.Now()
	finish.UpdateTime = time.Now()
	return repo.RepoAddDoc(apictx.CreateRepoCtx(), repo.CollectionFinish, &finish)
}

func DeleteFinish(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoDeleteDoc(apictx.CreateRepoCtx(), repo.CollectionFinish, _id)
}

func FinishList(c *gin.Context, apictx *ApiSession) (interface{}, error) {

	page, size, query := UtilQueryPageSize(c)
	return repo.RepoPageSearch(apictx.CreateRepoCtx(), &repo.PageSearchOptions{
		CollectName: repo.CollectionFinish,
		Page:        page,
		Size:        size,
		Query:       query,
	})
}

func FinishDetail(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	_id := c.Param("id")
	id, _ := primitive.ObjectIDFromHex(_id)
	if id.IsZero() {
		return nil, errors.New("id错误")
	}
	cate := &model.Finish{}
	found, err := repo.RepoSeachDoc(apictx.CreateRepoCtx(), &repo.DocSearchOptions{
		CollectName: repo.CollectionFinish,
		Query:       repo.Map{"_id": id},
	}, cate)
	if err != nil {
		log.Error(err)
		return nil, err
	}

	if !found {
		return nil, errors.New("未找到该数据")
	}
	return cate, nil
}

func UpdateFinish(c *gin.Context, apictx *ApiSession) (interface{}, error) {
	var cate model.Finish
	err := c.ShouldBindJSON(&cate)
	if err != nil {
		log.Error(err)
		return nil, err
	}
	if cate.Id.IsZero() {
		return nil, errors.New("id错误")
	}
	return repo.RepoUpdateSetDoc(apictx.CreateRepoCtx(), repo.CollectionFinish, cate.Id.Hex(), &cate)
}
